@@ -4,9 +4,7 @@ import joblib
 import tempfile
 import subprocess
 from io import BytesIO
-
-# from trell.utils import LogFormatter
-# LogFormatter.apply()
+from trell.utils import logger
 
 
 class S3:
@@ -27,13 +25,15 @@ class S3:
         key = sub_bucket + file_name
         try:
             s3 = boto3.resource('s3', aws_access_key_id=os.environ['ACCESS_KEY'],
-                                      aws_secret_access_key=os.environ['SECRET_KEY'])   
+                                      aws_secret_access_key=os.environ['SECRET_KEY'])  
+            logger.debug("Connected to S3 via environment credentials") 
         except:
             s3 = boto3.resource('s3')
+            logger.debug("Connected to S3 via IAM role")
              
 
         
-        print("Reading data from : " + bucket + "/" + key)
+        logger.info(f"Reading data from S3 path: {bucket}/{key}")
         with BytesIO() as data:
             s3.Bucket(bucket).download_fileobj(key, data)
             data.seek(0)
@@ -54,14 +54,15 @@ class S3:
         inserted = False
         key = '{}{}'.format(sub_bucket, file_name)
         compress = ('gzip', 3)
-        # logging.info("Writing data to : " + bucket + "/" + key)
-        print("Writing data to : " + bucket + '/' + key)
         try:
             s3 = boto3.resource('s3', aws_access_key_id=os.environ['ACCESS_KEY'],
-                                      aws_secret_access_key=os.environ['SECRET_KEY'])   
+                                      aws_secret_access_key=os.environ['SECRET_KEY'])  
+            logger.debug("Connected to S3 via environment credentials")  
         except:
             s3 = boto3.resource('s3')
-        
+            logger.debug("Connected to S3 via IAM role") 
+
+        logger.info(f"Writing data to S3 path : {bucket}/{key}")
         with tempfile.TemporaryFile() as data:
                     joblib.dump(python_data_object, data, compress=compress)
                     data.seek(0)
